@@ -608,7 +608,7 @@ sub Run {
     for my $AttachmentItem (@AttachmentList) {
         if ( !IsHashRefWithData($AttachmentItem) ) {
             return {
-                ErrorCode    => 'TicketUpdate.InvalidParameter',
+                ErrorCode => 'TicketUpdate.InvalidParameter',
                 ErrorMessage =>
                     "TicketUpdate: Ticket->Attachment parameter is invalid!",
             };
@@ -635,7 +635,6 @@ sub Run {
         TicketDynamicFields => $DynamicFieldList,
         AttachmentList      => \@AttachmentList,
         UserID              => $UserID,
-        PermissionUserID    => $PermissionUserID,
         UserType            => $UserType,
     );
 }
@@ -676,7 +675,7 @@ sub _CheckTicket {
         )
     {
         return {
-            ErrorCode    => 'TicketUpdate.InvalidParameter',
+            ErrorCode => 'TicketUpdate.InvalidParameter',
             ErrorMessage =>
                 "TicketUpdate: Ticket->CustomerUser parameter is invalid!",
         };
@@ -708,7 +707,7 @@ sub _CheckTicket {
     if ( $Ticket->{TypeID} || $Ticket->{Type} ) {
         if ( !$Self->ValidateType( %{$Ticket} ) ) {
             return {
-                ErrorCode    => 'TicketUpdate.InvalidParameter',
+                ErrorCode => 'TicketUpdate.InvalidParameter',
                 ErrorMessage =>
                     "TicketUpdate: Ticket->TypeID or Ticket->Type parameter is invalid!",
             };
@@ -731,7 +730,7 @@ sub _CheckTicket {
             )
         {
             return {
-                ErrorCode    => 'TicketUpdate.InvalidParameter',
+                ErrorCode => 'TicketUpdate.InvalidParameter',
                 ErrorMessage =>
                     "TicketUpdate: Ticket->ServiceID or Ticket->Service parameter is invalid!",
             };
@@ -757,7 +756,7 @@ sub _CheckTicket {
             )
         {
             return {
-                ErrorCode    => 'TicketUpdate.InvalidParameter',
+                ErrorCode => 'TicketUpdate.InvalidParameter',
                 ErrorMessage =>
                     "TicketUpdate: Ticket->SLAID or Ticket->SLA parameter is invalid!",
             };
@@ -790,7 +789,7 @@ sub _CheckTicket {
     if ( $Ticket->{OwnerID} || $Ticket->{Owner} ) {
         if ( !$Self->ValidateOwner( %{$Ticket} ) ) {
             return {
-                ErrorCode    => 'TicketUpdate.InvalidParameter',
+                ErrorCode => 'TicketUpdate.InvalidParameter',
                 ErrorMessage =>
                     "TicketUpdate: Ticket->OwnerID or Ticket->Owner parameter is invalid!",
             };
@@ -919,7 +918,7 @@ sub _CheckArticle {
         )
     {
         return {
-            ErrorCode    => 'TicketCreate.InvalidParameter',
+            ErrorCode => 'TicketCreate.InvalidParameter',
             ErrorMessage =>
                 "TicketCreate: Article->To parameter must be a valid email address when Article->ArticleSend is set!",
         };
@@ -1146,7 +1145,7 @@ sub _ValidateDynamicFields {
     for my $DynamicFieldItem (@$DynamicFieldList) {
         if ( !IsHashRefWithData($DynamicFieldItem) ) {
             return {
-                ErrorCode    => 'TicketUpdate.InvalidParameter',
+                ErrorCode => 'TicketUpdate.InvalidParameter',
                 ErrorMessage =>
                     "TicketUpdate: Ticket->DynamicField parameter is invalid!",
             };
@@ -1208,7 +1207,7 @@ sub _CheckDynamicField {
         )
     {
         return {
-            ErrorCode    => 'TicketUpdate.MissingParameter',
+            ErrorCode => 'TicketUpdate.MissingParameter',
             ErrorMessage =>
                 "TicketUpdate: To create an article DynamicField an article is required!",
         };
@@ -1354,13 +1353,9 @@ sub _CheckUpdatePermissions {
     # get ticket object
     my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
 
-    my $TicketPermissionFunctionName = $Param{UserType} eq 'Customer'
-        ? 'TicketCustomerPermission'
-        : 'TicketPermission';
-
     # check Article permissions
     if ( IsHashRefWithData($Article) ) {
-        my $Access = $TicketObject->$TicketPermissionFunctionName(
+        my $Access = $TicketObject->TicketPermission(
             Type     => 'note',
             TicketID => $TicketID,
             UserID   => $Param{UserID},
@@ -1375,7 +1370,7 @@ sub _CheckUpdatePermissions {
 
     # check dynamic field permissions
     if ( IsArrayRefWithData($DynamicFieldList) ) {
-        my $Access = $TicketObject->$TicketPermissionFunctionName(
+        my $Access = $TicketObject->TicketPermission(
             Type     => 'rw',
             TicketID => $TicketID,
             UserID   => $Param{UserID},
@@ -1390,7 +1385,7 @@ sub _CheckUpdatePermissions {
 
     # check queue permissions
     if ( $Ticket->{Queue} || $Ticket->{QueueID} ) {
-        my $Access = $TicketObject->$TicketPermissionFunctionName(
+        my $Access = $TicketObject->TicketPermission(
             Type     => 'move',
             TicketID => $TicketID,
             UserID   => $Param{UserID},
@@ -1405,7 +1400,7 @@ sub _CheckUpdatePermissions {
 
     # check owner permissions
     if ( $Ticket->{Owner} || $Ticket->{OwnerID} ) {
-        my $Access = $TicketObject->$TicketPermissionFunctionName(
+        my $Access = $TicketObject->TicketPermission(
             Type     => 'owner',
             TicketID => $TicketID,
             UserID   => $Param{UserID},
@@ -1420,7 +1415,7 @@ sub _CheckUpdatePermissions {
 
     # check responsible permissions
     if ( $Ticket->{Responsible} || $Ticket->{ResponsibleID} ) {
-        my $Access = $TicketObject->$TicketPermissionFunctionName(
+        my $Access = $TicketObject->TicketPermission(
             Type     => 'responsible',
             TicketID => $TicketID,
             UserID   => $Param{UserID},
@@ -1435,7 +1430,7 @@ sub _CheckUpdatePermissions {
 
     # check priority permissions
     if ( $Ticket->{Priority} || $Ticket->{PriorityID} ) {
-        my $Access = $TicketObject->$TicketPermissionFunctionName(
+        my $Access = $TicketObject->TicketPermission(
             Type     => 'priority',
             TicketID => $TicketID,
             UserID   => $Param{UserID},
@@ -1474,7 +1469,7 @@ sub _CheckUpdatePermissions {
         my $Access = 1;
 
         if ( $StateData{TypeName} =~ /^close/i ) {
-            $Access = $TicketObject->$TicketPermissionFunctionName(
+            $Access = $TicketObject->TicketPermission(
                 Type     => 'close',
                 TicketID => $TicketID,
                 UserID   => $Param{UserID},
@@ -1483,7 +1478,7 @@ sub _CheckUpdatePermissions {
 
         # set pending time
         elsif ( $StateData{TypeName} =~ /^pending/i ) {
-            $Access = $TicketObject->$TicketPermissionFunctionName(
+            $Access = $TicketObject->TicketPermission(
                 Type     => 'close',
                 TicketID => $TicketID,
                 UserID   => $Param{UserID},
@@ -1507,14 +1502,13 @@ sub _CheckUpdatePermissions {
 updates a ticket and creates an article and sets dynamic fields and attachments if specified.
 
     my $Response = $OperationObject->_TicketUpdate(
-        TicketID         => 123,
-        Ticket           => $Ticket,                  # all ticket parameters
-        Articles         => @Articles,                # all article parameters, optionally with dynamic fields
-        DynamicField     => $DynamicField,            # all ticket dynamic field parameters
-        Attachment       => $Attachment,              # all attachment parameters
-        UserID           => 123,
-        PermissionUserID => 201,                      # User for which permissions will be checked
-        UserType         => 'Agent'                   # || 'Customer
+        TicketID     => 123,
+        Ticket       => $Ticket,                  # all ticket parameters
+        Articles     => @Articles,                # all article parameters, optionally with dynamic fields
+        DynamicField => $DynamicField,            # all ticket dynamic field parameters
+        Attachment   => $Attachment,              # all attachment parameters
+        UserID       => 123,
+        UserType     => 'Agent'                   # || 'Customer
     );
 
     returns:
@@ -1545,10 +1539,7 @@ sub _TicketUpdate {
     my $TicketDynamicFields = $Param{TicketDynamicFields};
     my $AttachmentList      = $Param{AttachmentList};
 
-    my $Access = $Self->_CheckUpdatePermissions(
-        %Param,
-        UserID => $Param{PermissionUserID},
-    );
+    my $Access = $Self->_CheckUpdatePermissions(%Param);
 
     # if no permissions return error
     if ( !$Access->{Success} ) {
@@ -1589,7 +1580,7 @@ sub _TicketUpdate {
         );
         if ( !$Success ) {
             return {
-                Success      => 0,
+                Success => 0,
                 Errormessage =>
                     'Ticket title could not be updated, please contact system administrator!',
             };
@@ -1621,7 +1612,7 @@ sub _TicketUpdate {
 
         if ( !$Success ) {
             return {
-                Success      => 0,
+                Success => 0,
                 ErrorMessage =>
                     'Ticket queue could not be updated, please contact system administrator!',
             };
@@ -1653,7 +1644,7 @@ sub _TicketUpdate {
 
         if ( !$Success ) {
             return {
-                Success      => 0,
+                Success => 0,
                 Errormessage =>
                     'Ticket lock could not be updated, please contact system administrator!',
             };
@@ -1686,7 +1677,7 @@ sub _TicketUpdate {
 
         if ( !$Success ) {
             return {
-                Success      => 0,
+                Success => 0,
                 Errormessage =>
                     'Ticket type could not be updated, please contact system administrator!',
             };
@@ -1741,7 +1732,7 @@ sub _TicketUpdate {
 
                 if ( !$Success ) {
                     return {
-                        Success      => 0,
+                        Success => 0,
                         Errormessage =>
                             'Ticket pendig time could not be updated, please contact system'
                             . ' administrator!',
@@ -1780,7 +1771,7 @@ sub _TicketUpdate {
 
         if ( !$Success ) {
             return {
-                Success      => 0,
+                Success => 0,
                 Errormessage =>
                     'Ticket state could not be updated, please contact system administrator!',
             };
@@ -1798,7 +1789,7 @@ sub _TicketUpdate {
             if (
                 !$Self->ValidateSLA(
                     SLAID     => $TicketData{SLAID},
-                    Service   => $Ticket->{Service}   || '',
+                    Service   => $Ticket->{Service} || '',
                     ServiceID => $Ticket->{ServiceID} || '',
                 )
                 )
@@ -1846,7 +1837,7 @@ sub _TicketUpdate {
 
         if ( !$Success ) {
             return {
-                Success      => 0,
+                Success => 0,
                 Errormessage =>
                     'Ticket service could not be updated, please contact system administrator!',
             };
@@ -1888,7 +1879,7 @@ sub _TicketUpdate {
 
         if ( !$Success ) {
             return {
-                Success      => 0,
+                Success => 0,
                 Errormessage =>
                     'Ticket SLA could not be updated, please contact system administrator!',
             };
@@ -1932,7 +1923,7 @@ sub _TicketUpdate {
 
         if ( !$Success ) {
             return {
-                Success      => 0,
+                Success => 0,
                 Errormessage =>
                     'Ticket customer user could not be updated, please contact system administrator!',
             };
@@ -1965,7 +1956,7 @@ sub _TicketUpdate {
 
         if ( !$Success ) {
             return {
-                Success      => 0,
+                Success => 0,
                 Errormessage =>
                     'Ticket priority could not be updated, please contact system administrator!',
             };
@@ -2002,7 +1993,7 @@ sub _TicketUpdate {
 
         if ( !$Success ) {
             return {
-                Success      => 0,
+                Success => 0,
                 Errormessage =>
                     'Ticket owner could not be updated, please contact system administrator!',
             };
@@ -2042,7 +2033,7 @@ sub _TicketUpdate {
 
         if ( !$Success ) {
             return {
-                Success      => 0,
+                Success => 0,
                 Errormessage =>
                     'Ticket responsible could not be updated, please contact system administrator!',
             };
@@ -2167,7 +2158,7 @@ sub _TicketUpdate {
 
                 if ( !$Subject ) {
                     return {
-                        Success      => 0,
+                        Success => 0,
                         ErrorMessage =>
                             'The subject for the e-mail could not be generated. Please contact the system administrator'
                     };
@@ -2265,7 +2256,7 @@ sub _TicketUpdate {
                 NoAgentNotify        => $Article->{NoAgentNotify} || 0,
                 TicketID             => $TicketID,
                 SenderTypeID         => $Article->{SenderTypeID} || '',
-                SenderType           => $Article->{SenderType}   || '',
+                SenderType           => $Article->{SenderType} || '',
                 IsVisibleForCustomer => $Article->{IsVisibleForCustomer},
                 From                 => $From,
                 To                   => $To,
@@ -2273,8 +2264,8 @@ sub _TicketUpdate {
                 Bcc                  => $Bcc,
                 Subject              => $Subject,
                 Body                 => $Article->{Body},
-                MimeType             => $MimeType               || '',
-                Charset              => $Charset                || '',
+                MimeType             => $MimeType || '',
+                Charset              => $Charset || '',
                 ContentType          => $Article->{ContentType} || '',
                 UserID               => $Param{UserID},
                 HistoryType          => $Article->{HistoryType},
@@ -2345,7 +2336,7 @@ sub _TicketUpdate {
 
             if ( !$ArticleID ) {
                 return {
-                    Success      => 0,
+                    Success => 0,
                     ErrorMessage =>
                         'Article could not be created, please contact the system administrator'
                 };
@@ -2353,10 +2344,8 @@ sub _TicketUpdate {
 
             if ( $Article->{DynamicField} ) {
                 my $ArticleDynamicFieldList = _MakeArrayRef( $Article->{DynamicField} );
-                if (
-                    my $Result
-                    = $Self->_SetDynamicFields( $ArticleDynamicFieldList, $TicketID, $ArticleID, $Param{UserID} )
-                    )
+                if ( my $Result
+                    = $Self->_SetDynamicFields( $ArticleDynamicFieldList, $TicketID, $ArticleID, $Param{UserID} ) )
                 {
                     return $Result;
                 }
