@@ -13,7 +13,7 @@ use strict;
 use warnings;
 
 use Kernel::System::VariableCheck qw(:all);
-use Kernel::Language              qw(Translatable);
+use Kernel::Language qw(Translatable);
 
 our $ObjectManagerDisabled = 1;
 
@@ -594,7 +594,7 @@ sub Run {
                 qw(ServiceID OwnerID Owner ResponsibleID Responsible PriorityID Priority QueueID Queue Subject
                 Body IsVisibleForCustomer TypeID StateID State MergeToSelection MergeTo LinkTogether
                 EmailSubject EmailBody EmailTimeUnits
-                LinkTogetherParent Unlock MergeToChecked MergeToOldestChecked MarkTicketsAs)
+                LinkTogetherParent Unlock MergeToChecked MergeToOldestChecked MarkTicketsAsSeen MarkTicketsAsUnseen)
                 )
             {
                 $GetParam{$Key} = $ParamObject->GetParam( Param => $Key ) || '';
@@ -604,6 +604,15 @@ sub Run {
                 $GetParam{$Key} = $ParamObject->GetParam( Param => $Key );
             }
 
+            # get time stamp based on user time zone
+            %Time = $LayoutObject->TransformDateSelection(
+                Year   => $ParamObject->GetParam( Param => 'Year' ),
+                Month  => $ParamObject->GetParam( Param => 'Month' ),
+                Day    => $ParamObject->GetParam( Param => 'Day' ),
+                Hour   => $ParamObject->GetParam( Param => 'Hour' ),
+                Minute => $ParamObject->GetParam( Param => 'Minute' ),
+            );
+
             if ( $GetParam{'MergeToSelection'} eq 'OptionMergeTo' ) {
                 $GetParam{'MergeToChecked'} = 'checked';
             }
@@ -664,15 +673,6 @@ sub Run {
 
                 if ( $StateData{TypeName} =~ /^pending/i ) {
 
-                    # get time stamp based on user time zone
-                    %Time = $LayoutObject->TransformDateSelection(
-                        Year   => $ParamObject->GetParam( Param => 'Year' ),
-                        Month  => $ParamObject->GetParam( Param => 'Month' ),
-                        Day    => $ParamObject->GetParam( Param => 'Day' ),
-                        Hour   => $ParamObject->GetParam( Param => 'Hour' ),
-                        Minute => $ParamObject->GetParam( Param => 'Minute' ),
-                    );
-
                     # create datetime object
                     my $PendingDateTimeObject = $Kernel::OM->Create(
                         'Kernel::System::DateTime',
@@ -1319,44 +1319,36 @@ sub Run {
                 }
 
                 # watch or unwatch tickets
-                if ( defined $GetParam{'Watch'} ) {
-                    if ( $GetParam{'Watch'} eq '1' ) {
-                        $Result = $TicketObject->TicketWatchSubscribe(
-                            TicketID    => $TicketID,
-                            WatchUserID => $Self->{UserID},
-                            UserID      => $Self->{UserID},
-                        );
+                if ( $GetParam{'Watch'} eq '1' ) {
+                    $Result = $TicketObject->TicketWatchSubscribe(
+                        TicketID    => $TicketID,
+                        WatchUserID => $Self->{UserID},
+                        UserID      => $Self->{UserID},
+                    );
 
-                        if ( !$Result ) {
-                            push @NonUpdatedTickets, $Ticket{TicketNumber};
-                        }
+                    if ( !$Result ) {
+                        push @NonUpdatedTickets, $Ticket{TicketNumber};
                     }
-                    elsif ( $GetParam{'Watch'} eq '0' ) {
-                        $Result = $TicketObject->TicketWatchUnsubscribe(
-                            TicketID    => $TicketID,
-                            WatchUserID => $Self->{UserID},
-                            UserID      => $Self->{UserID},
-                        );
+                }
+                elsif ( $GetParam{'Watch'} eq '0' ) {
+                    $Result = $TicketObject->TicketWatchUnsubscribe(
+                        TicketID    => $TicketID,
+                        WatchUserID => $Self->{UserID},
+                        UserID      => $Self->{UserID},
+                    );
 
-                        if ( !$Result ) {
-                            push @NonUpdatedTickets, $Ticket{TicketNumber};
-                        }
+                    if ( !$Result ) {
+                        push @NonUpdatedTickets, $Ticket{TicketNumber};
                     }
                 }
 
-                if ( $GetParam{'MarkTicketsAs'} eq 'Seen' || $GetParam{'MarkTicketsAs'} eq 'Unseen' ) {
+                if ( $GetParam{'MarkTicketsAsSeen'} || $GetParam{'MarkTicketsAsUnseen'} ) {
+                    my $TicketActionFunction  = 'TicketFlagDelete';
+                    my $ArticleActionFunction = 'ArticleFlagDelete';
 
-                    my $TicketActionFunction;
-                    my $ArticleActionFunction;
-
-                    if ( $GetParam{'MarkTicketsAs'} eq 'Seen' ) {
+                    if ( $GetParam{'MarkTicketsAsSeen'} ) {
                         $TicketActionFunction  = 'TicketFlagSet';
                         $ArticleActionFunction = 'ArticleFlagSet';
-
-                    }
-                    elsif ( $GetParam{'MarkTicketsAs'} eq 'Unseen' ) {
-                        $TicketActionFunction  = 'TicketFlagDelete';
-                        $ArticleActionFunction = 'ArticleFlagDelete';
                     }
 
                     my @ArticleIDs = $ArticleObject->ArticleIndex(
@@ -1380,7 +1372,7 @@ sub Run {
                     $TicketObject->$TicketActionFunction(
                         TicketID => $TicketID,
                         Key      => 'Seen',
-                        Value    => 1,                 # irrelevant in case of delete
+                        Value    => 1,                      # irrelevant in case of delete
                         UserID   => $Self->{UserID},
                     );
                 }
@@ -1632,7 +1624,7 @@ sub _Mask {
                 %Param,
                 Format               => 'DateInputFormatLong',
                 DiffTime             => $ConfigObject->Get('Ticket::Frontend::PendingDiffTime') || 0,
-                Class                => $Param{Errors}->{DateInvalid}                           || '',
+                Class                => $Param{Errors}->{DateInvalid} || '',
                 Validate             => 1,
                 ValidateDateInFuture => 1,
             );
@@ -1847,16 +1839,18 @@ sub _Mask {
         );
     }
 
-    $Param{MarkTicketsAsOption} = $LayoutObject->BuildSelection(
-        Data => {
-            Seen   => 'Mark as seen',
-            Unseen => 'Mark as unseen',
-        },
-        Name         => 'MarkTicketsAs',
-        SelectedID   => $Param{MarkTicketsAs} // 0,
-        PossibleNone => 1,
-        Translation  => 1,
-        Class        => 'Modernize',
+    $Param{MarkTicketsAsSeenOption} = $LayoutObject->BuildSelection(
+        Data       => $ConfigObject->Get('YesNoOptions'),
+        Name       => 'MarkTicketsAsSeen',
+        SelectedID => $Param{MarkTicketsAsSeen} // 0,
+        Class      => 'Modernize',
+    );
+
+    $Param{MarkTicketsAsUnseenOption} = $LayoutObject->BuildSelection(
+        Data       => $ConfigObject->Get('YesNoOptions'),
+        Name       => 'MarkTicketsAsUnseen',
+        SelectedID => $Param{MarkTicketsAsUnseen} // 0,
+        Class      => 'Modernize',
     );
 
     # add rich text editor for note & email
@@ -1944,7 +1938,7 @@ sub _Mask {
         $DynamicFieldConfigs{ 'DynamicField_' . $DynamicFieldConfig->{Name} } = {
             Name              => $DynamicFieldConfig->{Name},
             RequireActivation => $RequireActivation || 'false',
-            IsChecked         => $IsChecked         || 'false',
+            IsChecked         => $IsChecked || 'false',
         };
 
         push @DynamicFieldNames, 'DynamicField_' . $DynamicFieldConfig->{Name};
