@@ -10,7 +10,6 @@ package Kernel::System::DBCRUD::Format;
 
 use strict;
 use warnings;
-use utf8;
 
 our @ObjectDependencies = (
     'Kernel::Config',
@@ -63,6 +62,7 @@ sub new {
         my $Module       = "Kernel::System::DBCRUD::Format::$Backend";
         my $LoadedModule = $MainObject->Require(
             $Module,
+            Silent => 1,
         );
 
         if ( !$LoadedModule ) {
