@@ -13,7 +13,7 @@ use strict;
 use warnings;
 use utf8;
 
-use File::Path  qw();
+use File::Path qw();
 use Time::HiRes qw(sleep);
 
 use parent qw(Kernel::System::Daemon::BaseDaemon);
@@ -70,11 +70,11 @@ sub new {
     # Get the NodeID from the SysConfig settings, this is used on High Availability systems.
     $Self->{NodeID} = $Self->{ConfigObject}->Get('NodeID') || 1;
 
-    # check NodeID, if it does not match, it's impossible to continue
-    if ( $Self->{NodeID} !~ m{\A[1-9]\d{0,2}\z} ) {
+    # Check NodeID, if does not match is impossible to continue.
+    if ( $Self->{NodeID} !~ m{ \A \d+ \z }xms && $Self->{NodeID} > 0 && $Self->{NodeID} < 1000 ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message  => "NodeID '$Self->{NodeID}' is invalid. Change it to a number between 1 and 999.",
+            Message  => "NodeID '$Self->{NodeID}' is invalid!",
         );
         return;
     }
