@@ -12,7 +12,6 @@ package Kernel::System::TemplateGenerator;
 
 use strict;
 use warnings;
-use utf8;
 
 use Kernel::Language;
 
@@ -119,8 +118,7 @@ sub Salutation {
     if ( $Self->{RichText} && $Salutation{ContentType} =~ /text\/plain/i ) {
         $Salutation{ContentType} = 'text/html';
         $Salutation{Text}        = $Kernel::OM->Get('Kernel::System::HTMLUtils')->ToHTML(
-            String                 => $Salutation{Text},
-            DoNotReplaceHardBreaks => 1,
+            String => $Salutation{Text},
         );
     }
 
@@ -147,7 +145,6 @@ sub Salutation {
         TicketData => \%Ticket,
         Data       => $Param{Data},
         UserID     => $Param{UserID},
-        Recipient  => $Param{Recipient},
     );
 
     # add urls
@@ -230,8 +227,7 @@ sub Signature {
     if ( $Self->{RichText} && $Signature{ContentType} =~ /text\/plain/i ) {
         $Signature{ContentType} = 'text/html';
         $Signature{Text}        = $Kernel::OM->Get('Kernel::System::HTMLUtils')->ToHTML(
-            String                 => $Signature{Text},
-            DoNotReplaceHardBreaks => 1,
+            String => $Signature{Text},
         );
     }
 
@@ -407,8 +403,7 @@ sub Template {
     {
         $Template{ContentType} = 'text/html';
         $Template{Template}    = $Kernel::OM->Get('Kernel::System::HTMLUtils')->ToHTML(
-            String                 => $Template{Template},
-            DoNotReplaceHardBreaks => 1,
+            String => $Template{Template},
         );
     }
 
@@ -489,7 +484,6 @@ sub Template {
     );
 
     if ( $Self->{RichText} ) {
-        $TemplateText =~ s/&amp;nbsp;/&nbsp;/g;
         $TemplateText =~ s/&lt;/</g;
         $TemplateText =~ s/&gt;/>/g;
         $TemplateText =~ s/&quot;/"/g;
@@ -546,8 +540,7 @@ sub GenericAgentArticle {
     {
         $Template{ContentType} = 'text/html';
         $Template{Body}        = $Kernel::OM->Get('Kernel::System::HTMLUtils')->ToHTML(
-            String                 => $Template{Body},
-            DoNotReplaceHardBreaks => 1,
+            String => $Template{Body},
         );
     }
 
@@ -645,7 +638,7 @@ sub Attributes {
     $Param{Data}->{Subject} = $TicketObject->TicketSubjectBuild(
         TicketNumber => $Ticket{TicketNumber},
         Subject      => $Param{Data}->{Subject} || '',
-        Action       => $Param{Action}          || '',
+        Action       => $Param{Action} || '',
     );
 
     # get sender address
@@ -666,7 +659,6 @@ generate response
         OrigHeader       => {},
         AutoResponseType => 'auto reply',
         UserID           => 123,
-        UserType         => 'Agent', # optional
     );
 
 =cut
@@ -768,8 +760,7 @@ sub AutoResponse {
     if ( $Self->{RichText} && $AutoResponse{ContentType} =~ /text\/plain/i ) {
         $AutoResponse{ContentType} = 'text/html';
         $AutoResponse{Text}        = $Kernel::OM->Get('Kernel::System::HTMLUtils')->ToHTML(
-            String                 => $AutoResponse{Text},
-            DoNotReplaceHardBreaks => 1,
+            String => $AutoResponse{Text},
         );
     }
 
@@ -850,9 +841,8 @@ sub AutoResponse {
         );
 
         $AutoResponse{Text} = $Kernel::OM->Get('Kernel::System::HTMLUtils')->DocumentComplete(
-            Charset  => 'utf-8',
-            String   => $AutoResponse{Text},
-            UserType => $Param{UserType} || 'Agent',
+            Charset => 'utf-8',
+            String  => $AutoResponse{Text},
         );
     }
 
@@ -1088,8 +1078,7 @@ sub NotificationEvent {
     if ( $Self->{RichText} && $Notification{ContentType} =~ /text\/plain/i ) {
         $Notification{ContentType} = 'text/html';
         $Notification{Body}        = $Kernel::OM->Get('Kernel::System::HTMLUtils')->ToHTML(
-            String                 => $Notification{Body},
-            DoNotReplaceHardBreaks => 1,
+            String => $Notification{Body},
         );
     }
 
@@ -1176,8 +1165,6 @@ sub _Replace {
         }
     }
 
-    my $HTMLUtilsObject = $Kernel::OM->Get('Kernel::System::HTMLUtils');
-
     # check for mailto links
     # since the subject and body of those mailto links are
     # uri escaped we have to uri unescape them, replace
@@ -1440,9 +1427,8 @@ sub _Replace {
             ATTRIBUTE:
             for my $Attribute ( sort keys %Recipient ) {
                 next ATTRIBUTE if !$Recipient{$Attribute};
-                $Recipient{$Attribute} = $HTMLUtilsObject->ToHTML(
-                    String                 => $Recipient{$Attribute},
-                    DoNotReplaceHardBreaks => 1,
+                $Recipient{$Attribute} = $Kernel::OM->Get('Kernel::System::HTMLUtils')->ToHTML(
+                    String => $Recipient{$Attribute},
                 );
             }
         }
@@ -1472,9 +1458,8 @@ sub _Replace {
             ATTRIBUTE:
             for my $Attribute ( sort keys %Owner ) {
                 next ATTRIBUTE if !$Owner{$Attribute};
-                $Owner{$Attribute} = $HTMLUtilsObject->ToHTML(
-                    String                 => $Owner{$Attribute},
-                    DoNotReplaceHardBreaks => 1,
+                $Owner{$Attribute} = $Kernel::OM->Get('Kernel::System::HTMLUtils')->ToHTML(
+                    String => $Owner{$Attribute},
                 );
             }
         }
@@ -1504,9 +1489,8 @@ sub _Replace {
             ATTRIBUTE:
             for my $Attribute ( sort keys %Responsible ) {
                 next ATTRIBUTE if !$Responsible{$Attribute};
-                $Responsible{$Attribute} = $HTMLUtilsObject->ToHTML(
-                    String                 => $Responsible{$Attribute},
-                    DoNotReplaceHardBreaks => 1,
+                $Responsible{$Attribute} = $Kernel::OM->Get('Kernel::System::HTMLUtils')->ToHTML(
+                    String => $Responsible{$Attribute},
                 );
             }
         }
@@ -1531,9 +1515,8 @@ sub _Replace {
         ATTRIBUTE:
         for my $Attribute ( sort keys %CurrentUser ) {
             next ATTRIBUTE if !$CurrentUser{$Attribute};
-            $CurrentUser{$Attribute} = $HTMLUtilsObject->ToHTML(
-                String                 => $CurrentUser{$Attribute},
-                DoNotReplaceHardBreaks => 1,
+            $CurrentUser{$Attribute} = $Kernel::OM->Get('Kernel::System::HTMLUtils')->ToHTML(
+                String => $CurrentUser{$Attribute},
             );
         }
     }
@@ -1556,9 +1539,8 @@ sub _Replace {
         ATTRIBUTE:
         for my $Attribute ( sort keys %Ticket ) {
             next ATTRIBUTE if !$Ticket{$Attribute};
-            $Ticket{$Attribute} = $HTMLUtilsObject->ToHTML(
-                String                 => $Ticket{$Attribute},
-                DoNotReplaceHardBreaks => 1,
+            $Ticket{$Attribute} = $Kernel::OM->Get('Kernel::System::HTMLUtils')->ToHTML(
+                String => $Ticket{$Attribute},
             );
         }
     }
@@ -1789,9 +1771,8 @@ sub _Replace {
             for my $Attribute ( sort keys %Data ) {
                 next ATTRIBUTE if !$Data{$Attribute};
 
-                $Data{$Attribute} = $HTMLUtilsObject->ToHTML(
-                    String                 => $Data{$Attribute},
-                    DoNotReplaceHardBreaks => 1,
+                $Data{$Attribute} = $Kernel::OM->Get('Kernel::System::HTMLUtils')->ToHTML(
+                    String => $Data{$Attribute},
                 );
             }
         }
@@ -1851,16 +1832,9 @@ sub _Replace {
                         $NewOldBody =~ s/(<br\/>)\s{0,20}$//gs;
                     }
 
-                    # replace hard breaks with paragraphs before there will
-                    # be added any "HTML" content like blockquote that would
-                    # make it complex to replace hard breaks afterwards
-                    $NewOldBody = $HTMLUtilsObject->ToHTMLReplaceWithParagraphs(
-                        String => $NewOldBody,
-                    );
-
                     # add quote
                     $NewOldBody = "<blockquote type=\"cite\">$NewOldBody</blockquote>";
-                    $NewOldBody = $HTMLUtilsObject->DocumentCleanup(
+                    $NewOldBody = $Kernel::OM->Get('Kernel::System::HTMLUtils')->DocumentCleanup(
                         String => $NewOldBody,
                     );
                 }
@@ -1989,9 +1963,8 @@ sub _Replace {
             ATTRIBUTE:
             for my $Attribute ( sort keys %CustomerUser ) {
                 next ATTRIBUTE if !$CustomerUser{$Attribute};
-                $CustomerUser{$Attribute} = $HTMLUtilsObject->ToHTML(
-                    String                 => $CustomerUser{$Attribute},
-                    DoNotReplaceHardBreaks => 1,
+                $CustomerUser{$Attribute} = $Kernel::OM->Get('Kernel::System::HTMLUtils')->ToHTML(
+                    String => $CustomerUser{$Attribute},
                 );
             }
         }
@@ -2007,10 +1980,6 @@ sub _Replace {
     $Tag = $Start . 'OTRS_AGENT_';
     $Param{Text} =~ s/$Tag.+?$End/-/gi;
 
-    $Param{Text} = $HTMLUtilsObject->ToHTMLReplaceWithParagraphs(
-        String => $Param{Text},
-    ) if ( $Param{RichText} );
-
     return $Param{Text};
 }
 
