@@ -70,7 +70,7 @@ sub Run {
     }
 
     my $SuccessfulMigration = 1;
-    my @Components          = ( 'CheckPreviousRequirement', 'Run', 'FollowUp' );
+    my @Components          = ( 'CheckPreviousRequirement', 'Run' );
 
     COMPONENT:
     for my $Component (@Components) {
@@ -115,41 +115,17 @@ sub _ExecuteComponent {
     # Get migration tasks.
     my @Tasks = $Self->_TasksGet();
 
-    # Get the number of total steps by counting only tasks with Run function.
-    my $Steps = 0;
-    TASK:
-    for my $Task (@Tasks) {
-        next TASK if !$Task;
-        next TASK if !$Task->{Module};
-
-        my $ModuleName = "$Task->{Module}";
-
-        # ObjectParamAdd
-        $Kernel::OM->ObjectParamAdd(
-            "$Task->{Module}" => {
-                Opts => $Self->{Opts},
-            },
-        );
-
-        $Self->{TaskObjects}->{$ModuleName} //= $Kernel::OM->Create($ModuleName);
-
-        if ( $Self->{TaskObjects}->{$ModuleName} && $Self->{TaskObjects}->{$ModuleName}->can($Component) ) {
-            $Steps++;
-        }
-    }
-
+    # Get the number of total steps.
+    my $Steps               = scalar @Tasks;
     my $CurrentStep         = 1;
     my $SuccessfulMigration = 1;
 
     # Show initial message for current component
-    if ( $Steps && $Component eq 'CheckPreviousRequirement' ) {
-        print "\n Checking requirements... \n\n";
+    if ( $Component eq 'Run' ) {
+        print "\n Executing tasks ... \n\n";
     }
-    elsif ( $Steps && $Component eq 'Run' ) {
-        print "\n Executing tasks... \n\n";
-    }
-    elsif ( $Steps && $Component eq 'FollowUp' ) {
-        print "\n Executing follow-up tasks... \n\n";
+    else {
+        print "\n Checking requirements ... \n\n";
     }
 
     TASK:
@@ -169,6 +145,14 @@ sub _ExecuteComponent {
             $TaskStartTime = Time::HiRes::time();
         }
 
+        # Run module.
+        $Kernel::OM->ObjectParamAdd(
+            "$Task->{Module}" => {
+                Opts => $Self->{Opts},
+            },
+        );
+
+        $Self->{TaskObjects}->{$ModuleName} //= $Kernel::OM->Create($ModuleName);
         if ( !$Self->{TaskObjects}->{$ModuleName} ) {
             print "\n    Error: Could not create object for: $ModuleName.\n\n";
             $SuccessfulMigration = 0;
@@ -178,11 +162,17 @@ sub _ExecuteComponent {
         my $Success = 1;
 
         # Execute Run-Component
-        if ( $Self->{TaskObjects}->{$ModuleName}->can($Component) ) {
+        if ( $Component eq 'Run' ) {
             print "    Step $CurrentStep of $Steps: $Task->{Message} ...\n";
             $Success = $Self->{TaskObjects}->{$ModuleName}->$Component(%Param);
         }
 
+        # Execute previous check, printing a different message
+        elsif ( $Self->{TaskObjects}->{$ModuleName}->can($Component) ) {
+            print "    Requirement check for: $Task->{Message} ...\n";
+            $Success = $Self->{TaskObjects}->{$ModuleName}->$Component(%Param);
+        }
+
         # Do not handle timing if task has no appropriate component.
         else {
             next TASK;
@@ -199,10 +189,7 @@ sub _ExecuteComponent {
             last TASK;
         }
 
-        # Only increment step counter if the component was actually executed
-        if ( $Self->{TaskObjects}->{$ModuleName}->can($Component) ) {
-            $CurrentStep++;
-        }
+        $CurrentStep++;
     }
 
     return $SuccessfulMigration;
@@ -234,14 +221,6 @@ sub _TasksGet {
             Message => 'Check database default storage engine',
             Module  => 'scripts::Migration::Base::DatabaseDefaultStorageEngineCheck',
         },
-
-        # 7.3 specific tasks before database migration
-        {
-            Message => 'Phone state settings migration notice',
-            Module  => 'scripts::Migration::Znuny::MigratePhoneStateSettings',
-        },
-
-        # Base
         {
             Message => 'Upgrade database structure',
             Module  => 'scripts::Migration::Znuny::UpgradeDatabaseStructure',
@@ -258,19 +237,30 @@ sub _TasksGet {
             Message => 'Rebuild configuration',
             Module  => 'scripts::Migration::Base::RebuildConfig',
         },
-
-        # 7.3 specific tasks after database migration
-        # ...to be added here...
-
-        # Base tasks after database migration
         {
             Message => 'Migrate DBCRUD UUID columns',
             Module  => 'scripts::Migration::Znuny::MigrateDBCRUDUUIDColumns',
         },
+        {
+            Message => 'Migrate notification events',
+            Module  => 'scripts::Migration::Znuny::MigrateNotificationEvents',
+        },
+        {
+            Message => 'Integrate Znuny-MarkTicketSeenUnseen',
+            Module  => 'scripts::Migration::Znuny::IntegrateZnunyMarkTicketSeenUnseen',
+        },
+        {
+            Message => 'Migrate groups',
+            Module  => 'scripts::Migration::Znuny::MigrateGroups',
+        },
         {
             Message => 'Migrate SysConfig settings',
             Module  => 'scripts::Migration::Znuny::MigrateSysConfigSettings',
         },
+        {
+            Message => 'Cleanup orphaned mentions',
+            Module  => 'scripts::Migration::Znuny::CleanupOrphanedMentions',
+        },
 
         # NOTE: UninstallMergedPackages has to be called only after
         # SysConfig settings of the merged packages have been migrated.
@@ -278,15 +268,6 @@ sub _TasksGet {
             Message => 'Uninstall merged packages',
             Module  => 'scripts::Migration::Znuny::UninstallMergedPackages',
         },
-        {
-            Message => 'Remove mention flag from archived tickets.',
-            Module  => 'scripts::Migration::Znuny::RemoveMentionFlagFromArchivedTickets',
-        },
-
-        # 7.3 specific tasks after SysConfig migration
-        # ...to be added here...
-
-        # Base tasks after SysConfig migration
         {
             Message => 'Initialize default cron jobs',
             Module  => 'scripts::Migration::Base::InitializeDefaultCronjobs',
