@@ -81,7 +81,7 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
 
         // Depending on Action initialize specific functions
         if (Core.Config.Get('Action') === 'AdminProcessManagementPath' && Subaction !== 'ClosePopup') {
-           TargetNS.InitPathEdit();
+            TargetNS.InitPathEdit();
         }
 
         // Initialize ajax call for updating default config parameter
@@ -117,7 +117,7 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
             return false;
         });
 
-        $('a.AsPopup_Redirect').on('click', function () {
+        $('a.AsPopup_Redirect').off('click.AsPopup_Redirect').on('click.AsPopup_Redirect', function () {
             var $Form = $(this).closest('form');
 
             $('#PopupRedirect').val(1);
@@ -233,13 +233,14 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
             [
                 {
                     Label: Core.Language.Translate('Cancel'),
+                    Type: 'Secondary',
                     Function: function () {
                         Core.UI.Dialog.CloseDialog($('.Dialog'));
                     }
                 },
                 {
                     Label: Core.Language.Translate('Delete'),
-                    Class: 'Primary',
+                    Type: 'Warning',
                     Function: function () {
                         var Data = {
                                 Action: 'AdminProcessManagement',
@@ -299,13 +300,14 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
             [
                 {
                     Label: Core.Language.Translate('Cancel'),
+                    Type: 'Secondary',
                     Function: function () {
                         Core.UI.Dialog.CloseDialog($('.Dialog'));
                     }
                 },
                 {
                     Label: Core.Language.Translate('Delete'),
-                    Class: 'Primary',
+                    Type: 'Warning',
                     Function: function () {
                         var Data = {
                                 Action: 'AdminProcessManagement',
@@ -402,16 +404,16 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
      *      Initializes all event handler to drag and drop elements from the accordion to the canvas.
      */
     TargetNS.InitAccordionDnD = function () {
-      /**
-       * @private
-       * @name GetMousePosition
-       * @memberof Core.Agent.Admin.ProcessManagement.InitAccordionDND
-       * @function
-       * @returns {Object} Mouse position.
-       * @param {Object} Event - The event object.
-       * @description
-       *      Calculates mouse position.
-       */
+        /**
+        * @private
+        * @name GetMousePosition
+        * @memberof Core.Agent.Admin.ProcessManagement.InitAccordionDND
+        * @function
+        * @returns {Object} Mouse position.
+        * @param {Object} Event - The event object.
+        * @description
+        *      Calculates mouse position.
+        */
         function GetMousePosition(Event) {
             var PosX = 0,
                 PosY = 0;
@@ -430,16 +432,16 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
             return {left: PosX, top: PosY};
         }
 
-      /**
-       * @private
-       * @name GetPositionOnCanvas
-       * @memberof Core.Agent.Admin.ProcessManagement.InitAccordionDND
-       * @function
-       * @returns {Object} Position of mouse on canvas.
-       * @param {Object} Event - The event object.
-       * @description
-       *      Calculates mouse position relative to canvas object.
-       */
+        /**
+        * @private
+        * @name GetPositionOnCanvas
+        * @memberof Core.Agent.Admin.ProcessManagement.InitAccordionDND
+        * @function
+        * @returns {Object} Position of mouse on canvas.
+        * @param {Object} Event - The event object.
+        * @description
+        *      Calculates mouse position relative to canvas object.
+        */
         function GetPositionOnCanvas(Event) {
             var $Canvas = $('#Canvas'),
                 CanvasPosition,
@@ -455,16 +457,16 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
             return {left: PosX, top: PosY};
         }
 
-      /**
-       * @private
-       * @name AddActivityToCanvas
-       * @memberof Core.Agent.Admin.ProcessManagement.InitAccordionDND
-       * @function
-       * @param {Object} Event - The event object.
-       * @param {Object} UI - jQuery UI object.
-       * @description
-       *      Adds activity to the canvas after drop event.
-       */
+        /**
+        * @private
+        * @name AddActivityToCanvas
+        * @memberof Core.Agent.Admin.ProcessManagement.InitAccordionDND
+        * @function
+        * @param {Object} Event - The event object.
+        * @param {Object} UI - jQuery UI object.
+        * @description
+        *      Adds activity to the canvas after drop event.
+        */
         function AddActivityToCanvas(Event, UI) {
             var Position = GetPositionOnCanvas(Event),
                 EntityID = $(UI.draggable).data('entity'),
@@ -517,16 +519,16 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
             }
         }
 
-      /**
-       * @private
-       * @name CheckIfMousePositionIsOverActivity
-       * @memberof Core.Agent.Admin.ProcessManagement.InitAccordionDND
-       * @function
-       * @returns {String|Boolean} Returns ID of activity or false, if mouse is not over an activity.
-       * @param {Object} Position - A mouse position object.
-       * @description
-       *      Checks if mouse position is over an activity (e.g. to drop activity dialogs to an activity).
-       */
+        /**
+        * @private
+        * @name CheckIfMousePositionIsOverActivity
+        * @memberof Core.Agent.Admin.ProcessManagement.InitAccordionDND
+        * @function
+        * @returns {String|Boolean} Returns ID of activity or false, if mouse is not over an activity.
+        * @param {Object} Position - A mouse position object.
+        * @description
+        *      Checks if mouse position is over an activity (e.g. to drop activity dialogs to an activity).
+        */
         function CheckIfMousePositionIsOverActivity(Position) {
             var ProcessEntityID = $('#ProcessEntityID').val(),
                 Path = TargetNS.ProcessData.Process[ProcessEntityID].Path,
@@ -548,16 +550,16 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
             return ActivityMatch;
         }
 
-      /**
-       * @private
-       * @name AddActivityDialogToCanvas
-       * @memberof Core.Agent.Admin.ProcessManagement.InitAccordionDND
-       * @function
-       * @param {Object} Event - The event object.
-       * @param {Object} UI - jQuery UI object.
-       * @description
-       *      Adds activity dialog to the canvas after drop event.
-       */
+        /**
+        * @private
+        * @name AddActivityDialogToCanvas
+        * @memberof Core.Agent.Admin.ProcessManagement.InitAccordionDND
+        * @function
+        * @param {Object} Event - The event object.
+        * @param {Object} UI - jQuery UI object.
+        * @description
+        *      Adds activity dialog to the canvas after drop event.
+        */
         function AddActivityDialogToCanvas(Event, UI) {
             var Position = GetPositionOnCanvas(Event),
                 EntityID = $(UI.draggable).data('entity'),
@@ -607,16 +609,16 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
             }
         }
 
-      /**
-       * @private
-       * @name DummyActivityConnected
-       * @memberof Core.Agent.Admin.ProcessManagement.InitAccordionDND
-       * @function
-       * @returns {Boolean} True if a dummy endpoint was found, false otherwise.
-       * @param {String} ProcessEntityID - The process ID.
-       * @description
-       *      Check if any transition has a dummy endpoint.
-       */
+        /**
+        * @private
+        * @name DummyActivityConnected
+        * @memberof Core.Agent.Admin.ProcessManagement.InitAccordionDND
+        * @function
+        * @returns {Boolean} True if a dummy endpoint was found, false otherwise.
+        * @param {String} ProcessEntityID - The process ID.
+        * @description
+        *      Check if any transition has a dummy endpoint.
+        */
         function DummyActivityConnected(ProcessEntityID) {
             var DummyFound = false;
             $.each(TargetNS.ProcessData.Process[ProcessEntityID].Path, function (Activity, ActivityData) {
@@ -629,17 +631,17 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
             return DummyFound;
         }
 
-      /**
-       * @private
-       * @name AddTransitionToCanvas
-       * @memberof Core.Agent.Admin.ProcessManagement.InitAccordionDND
-       * @function
-       * @returns {Boolean} False if a another unconnected transition is on the canvas
-       * @param {Object} Event - The event object.
-       * @param {Object} UI - jQuery UI object.
-       * @description
-       *      Adds transition to the canvas after drop event.
-       */
+        /**
+        * @private
+        * @name AddTransitionToCanvas
+        * @memberof Core.Agent.Admin.ProcessManagement.InitAccordionDND
+        * @function
+        * @returns {Boolean} False if a another unconnected transition is on the canvas
+        * @param {Object} Event - The event object.
+        * @param {Object} UI - jQuery UI object.
+        * @description
+        *      Adds transition to the canvas after drop event.
+        */
         function AddTransitionToCanvas(Event, UI) {
             var Position = GetPositionOnCanvas(Event),
                 EntityID = $(UI.draggable).data('entity'),
@@ -695,17 +697,17 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
             }
         }
 
-      /**
-       * @private
-       * @name AddTransitionActionToCanvas
-       * @memberof Core.Agent.Admin.ProcessManagement.InitAccordionDND
-       * @function
-       * @returns {Boolean} Returns false, if transition is not defined.
-       * @param {Object} Event - The event object.
-       * @param {Object} UI - jQuery UI object.
-       * @description
-       *      Adds transition action to the canvas after drop event.
-       */
+        /**
+        * @private
+        * @name AddTransitionActionToCanvas
+        * @memberof Core.Agent.Admin.ProcessManagement.InitAccordionDND
+        * @function
+        * @returns {Boolean} Returns false, if transition is not defined.
+        * @param {Object} Event - The event object.
+        * @param {Object} UI - jQuery UI object.
+        * @description
+        *      Adds transition action to the canvas after drop event.
+        */
         function AddTransitionActionToCanvas(Event, UI) {
             var EntityID = $(UI.draggable).data('entity'),
                 Entity = TargetNS.ProcessData.TransitionAction[EntityID],
@@ -968,7 +970,7 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
      *      Initialize process edit screen.
      */
     TargetNS.InitProcessEdit = function () {
-      var ConfigProcess = Core.Config.Get('ConfigProcess');
+        var ConfigProcess = Core.Config.Get('ConfigProcess');
 
         // Get Process Data
         TargetNS.ProcessData = {
@@ -1241,7 +1243,9 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
                                     FieldConfigElement.Config = {};
                                 }
 
-                                CKEDITOR.instances['Body'].updateElement();
+                                if (typeof CKEDITOR !== 'undefined') {
+                                    CKEDITOR.instances['Body'].updateElement();
+                                }
                                 FieldConfigElement.Config.Subject = $('#Subject').val();
                                 FieldConfigElement.Config.Body = $('#Body').val();
 
@@ -1640,7 +1644,7 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
 
         // set current start and end activity (just for information purposes, not changeable)
         $.each(PathInfo, function(Activity, Transition) {
-            if (Activity === StartActivityID && typeof Transition[CurrentTransitionEntityID] !== 'undefined') {
+            if (Activity === StartActivityID && typeof Transition[CurrentTransitionEntityID].ActivityEntityID !== 'undefined') {
                 $('#StartActivity').attr('title', ActivityInfo[Activity].Name).text(ActivityInfo[Activity].Name);
                 $('#EndActivity').attr('title', ActivityInfo[Transition[CurrentTransitionEntityID].ActivityEntityID].Name).text(ActivityInfo[Transition[CurrentTransitionEntityID].ActivityEntityID].Name);
 
@@ -1665,7 +1669,7 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
 
         // if transition select is updated, also update transition edit link
         $('#Transition').on('change', function () {
-           $('#EditPath a').data('entity', $(this).val());
+            $('#EditPath a').data('entity', $(this).val());
         });
 
         $('#Submit').on('click', function() {
